@@ -1,10 +1,14 @@
 `%||%` <- function(x, y) {
-  if (is.null(x)) return(y)
+  if (is.null(x)) {
+    return(y)
+  }
   x
 }
 
 `%~~%` <- function(x, y) {
-  if (length(x) == 0L) return(y)
+  if (length(x) == 0L) {
+    return(y)
+  }
   x
 }
 
@@ -15,10 +19,11 @@ convert_nas <- function(tbl, replace_with = 0L) {
 
 convert_email_to_cran_format <- function(email) {
   ## check email
-  lapply(email, function(x)
+  lapply(email, function(x) {
     if (!grepl("\\@", x)) {
       stop("Malformed email address: ", sQuote(email), call. = FALSE)
-    })
+    }
+  })
   email <- gsub("\\@", "_at_", tolower(email))
   ##  "all characters different from letters, digits, hyphens,
   ##  underscores, colons, and periods replaced by underscores ..."
@@ -32,9 +37,9 @@ add_cols <- function(tbl) {
   if (length(to_add) > 0) {
     col_to_add <- replicate(length(to_add), list(rep(0L, nrow(tbl))))
     names(col_to_add) <- to_add
-    col_to_add <- as.tibble(col_to_add)
+    col_to_add <- as_tibble(col_to_add)
     res <- cbind(tbl, col_to_add)
-    tbl <- tibble::as.tibble(res)
+    tbl <- tibble::as_tibble(res)
   }
   convert_nas(tbl)[, names(default_cran_results)]
 }
